@@ -1,7 +1,7 @@
 /*
     gui.h - Part of xsensors
 
-    Copyright (c) 2002 Kris Kersey <augustus@linuxhardware.org>
+    Copyright (c) 2002-2007 Kris Kersey <augustus@linuxhardware.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,20 +19,17 @@
 */
 
 #include <sys/stat.h>
-#include <math.h>
 #include <gdk/gdk.h>
 
-enum { VOLT, TEMP, FAN, EEPROM };
+enum { VOLT, TEMP, FAN };
 
 #define NA "Not Available!"
 
 /* Prototypes */
-gint round( double );
 gint destroy_gui( GtkWidget *, gpointer );
-void get_pm_location( int, int * );
 gboolean expose_event_callback( GtkWidget *, GdkEventExpose *, gpointer );
 gint free_llist( updates * );
 gint update_sensor_data( gpointer );
 gint start_timer( GtkWidget *, gpointer );
-updates *add_sensor_tab( GtkWidget *, sensors_chip_name );
+updates *add_sensor_tab( GtkWidget *, const sensors_chip_name * );
 int start_gui( int, char ** );
