@@ -1,7 +1,7 @@
 /*
     main.h - Part of xsensors
 
-    Copyright (c) 2002 Kris Kersey <augustus@linuxhardware.org>
+    Copyright (c) 2002-2007 Kris Kersey <augustus@linuxhardware.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,21 +25,16 @@
 #include <unistd.h>
 #include <errno.h>
 #include <sensors/sensors.h>
-#include <sensors/chips.h>
 #include <glib.h>
 #include <gtk/gtk.h>
 #include "chips.h"
 #include "gui.h"
 
 /* Version Number */
-#define VERSION "0.50"
-
-/* Default lm_sensors config file */
-#define DEFAULT_SENS_CONF "/etc/sensors.conf"
+#define VERSION "0.70"
 
 /* Pretty identifiers. */
 enum { SUCCESS, FAILURE };
 
 /* Prototypes */
 int help_msg( void );
-int print_features( sensors_chip_name );
